#
# spec file for package sblim-cmpi-nfsv4
#
# Copyright (c) 2012 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           sblim-cmpi-nfsv4
BuildRequires:  bison
BuildRequires:  flex
BuildRequires:  gcc-c++
BuildRequires:  openssl-devel
BuildRequires:  pam-devel
BuildRequires:  sblim-cmpi-base-devel
BuildRequires:  sblim-indication_helper-devel
BuildRequires:  sblim-sfcb
BuildRequires:  sblim-testsuite
%if 0%{?suse_version}
BuildRequires:  openslp-devel
%endif
Url:            http://sblim.wiki.sourceforge.net/
Summary:        SBLIM CMPI NFSv4 Instrumentation
License:        EPL-1.0
Group:          System/Management
Version:        1.1.0
Release:        4.1
Requires:       sblim-cmpi-base >= 1.2.3, cim-server
Source0:        http://prdownloads.sourceforge.net/sblim/sblim-cmpi-nfsv4-%{version}.tar.bz2
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
#!BuildIgnore:  tog-pegasus

%description
Standards Based Linux NFSv4 Instrumentation Providers



Authors:
--------
    SBLIM Project

%prep
%setup

%build
%configure --disable-static
%{__make}

%install
%if 0%{?suse_version}
%makeinstall docdir=%{_docdir}/%{name}
%else
make install DESTDIR=%{buildroot} docdir=%{_docdir}/%{name}-%{version}
%endif
rm %buildroot%_libdir/cmpi/*.la
rm %buildroot%_libdir/*.la

%clean
%{__rm} -rf $RPM_BUILD_ROOT

%post
%define mofs Linux_NFSv4SystemSetting,Linux_NFSv4SystemConfiguration
%define PEGASUS_MOF CIM_SystemSetting,CIM_NFS,CIM_SystemConfiguration,CIM_SystemSettingContext
# compile MOF
/sbin/ldconfig
# Register Schema and Provider - this is higly provider specific  
# tog-pegasus needs some schemes registered first  
if [ -x /usr/bin/peg-loadmof.sh ]; then  
    peg-loadmof.sh -n root/cimv2 /usr/share/mof/cim-current/*/{%{PEGASUS_MOF}}.mof  
    rctog-pegasus try-restart  
fi  
# and then following script can handle registration for various providers  
d=%_datadir/%name
$d/provider-register.sh -r $d/{%{mofs}}.registration -m $d/{%{mofs}}.mof

%preun
if [ "$1" = "0" ]; then
	d=%_datadir/%name
	$d/provider-register.sh -d -r $d/{%{mofs}}.registration -m $d/{%{mofs}}.mof
fi

%files
%defattr(-,root,root) 
%if 0%{?suse_version}
%doc %{_docdir}/%{name}
%else
%doc %{_docdir}/%{name}-%{version}
%endif
%{_libdir}/cmpi/*.so
%{_libdir}/*.so
%{_datadir}/%{name}
%{_datadir}/sblim-testsuite/*

%changelog
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Mon Sep 13 2010 kkaempf@novell.com
- Fix RHEL build
* Thu Oct  1 2009 mhrusecky@suse.cz
- updated to 1.1.0
  - updated URL for CPL
  - migrate provider licenses to EPL
  - fixed upstream bugs:
  * 1652311 fixes compile errors with gcc4
  * 1457924 Various Compile Warnings
* Tue May 12 2009 mhrusecky@suse.cz
- ignoring tog-pegasus during build
* Fri Sep 12 2008 mmarek@suse.cz
- switch to sfcb
* Thu Nov  1 2007 mmarek@suse.cz
- updated to 1.0.12
  fixed upstream bugs:
  * 1199129 Providers won't compile with CMPI 1.0
  * 1600348 Fixed association behaviour if /etc/exports
    file is empty
- removed static libs
* Thu Mar 29 2007 rguenther@suse.de
- add bison and flex BuildRequires
* Wed Mar  1 2006 mrueckert@suse.de
- update to 1.0.11 [#144214]
- dropped all patches as the build system changed
- added sblim-cmpi-nfsv4-1.0.11_syntax.patch
  fixes a few compiler warnings in the lex/yacc generated code
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Dec  9 2005 mrueckert@suse.de
- upgrade to 1.0.10
- build with openwbem
- fix some syntax errors
* Wed Apr 27 2005 ro@suse.de
- build with gcc4
* Thu Nov 11 2004 ro@suse.de
- fixed file list
* Sun May 16 2004 nashif@suse.de
- #40661: SBLIM cmpi-nfsv3/4 reports error on empty
  /etc/exports file
- V. 1.0.8
* Thu May 13 2004 nashif@suse.de
- #39756: cmpinfsv3 provider does not return associations for
  Linux_NFSv3SystemConfiguration class
- Do not De-register when updating package
* Mon May 10 2004 nashif@suse.de
- Dereigster providers when uninstalling (#39667)
- test scripts incorrectly check file read/write permission (#40262)
* Mon May 10 2004 nashif@suse.de
- Bug #39754:  wbemri & wbemrin fail to parse query results
  from Pegasus cimom
* Fri May  7 2004 nashif@suse.de
- Bug #39750: NFS providers not returning object path when
  creating new instance
* Fri Apr 30 2004 nashif@suse.de
- Update to version 1.0.2
* Fri Apr 16 2004 nashif@suse.de
- Update version with bugfixes from IBM
* Wed Apr 14 2004 nashif@suse.de
- Added PreReq for loadmof.sh
* Wed Apr  7 2004 nashif@suse.de
- Initial Release
